0.9.9 API documentation: epsilon.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
epsilon.hpp File Reference

GLM_GTC_epsilon More...

Go to the source code of this file.

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, bool, Q > | epsilonEqual (vec< L, T, Q > const &x, vec< L, T, Q > const &y, T const &epsilon)
| Returns the component-wise comparison of |x - y| < epsilon. More...
template<typename genType >
GLM_FUNC_DECL bool | epsilonEqual (genType const &x, genType const &y, genType const &epsilon)
| Returns the component-wise comparison of |x - y| < epsilon. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, bool, Q > | epsilonNotEqual (vec< L, T, Q > const &x, vec< L, T, Q > const &y, T const &epsilon)
| Returns the component-wise comparison of |x - y| < epsilon. More...
template<typename genType >
GLM_FUNC_DECL bool | epsilonNotEqual (genType const &x, genType const &y, genType const &epsilon)
| Returns the component-wise comparison of |x - y| >= epsilon. More...

## Detailed Description

GLM_GTC_epsilon

See also
  Core features (dependence)
  GLM_GTC_quaternion (dependence)

Definition in file epsilon.hpp.